@@ -5,8 +5,8 @@ import (
 
 	"github.com/openshift/library-go/pkg/controller/controllercmd"
 
-	"github.com/open-cluster-management/registration-operator/pkg/operators"
-	"github.com/open-cluster-management/registration-operator/pkg/version"
+	"open-cluster-management.io/registration-operator/pkg/operators"
+	"open-cluster-management.io/registration-operator/pkg/version"
 )
 
 // NewKlusterletOperatorCmd generatee a command to start klusterlet operator
