@@ -13,7 +13,7 @@ import (
 
 	"github.com/onsi/gomega"
 
-	certificatesv1beta1 "k8s.io/api/certificates/v1beta1"
+	certificatesv1 "k8s.io/api/certificates/v1"
 	coordv1 "k8s.io/api/coordination/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -151,8 +151,8 @@ func (t *Tester) CreateKlusterlet(name, clusterName, agentNamespace string) (*op
 			Name: name,
 		},
 		Spec: operatorapiv1.KlusterletSpec{
-			RegistrationImagePullSpec: "quay.io/open-cluster-management/registration:latest",
-			WorkImagePullSpec:         "quay.io/open-cluster-management/work:latest",
+			RegistrationImagePullSpec: "quay.io/stolostron/registration:release-2.4",
+			WorkImagePullSpec:         "quay.io/stolostron/work:release-2.4",
 			ExternalServerURLs: []operatorapiv1.ServerURL{
 				{
 					URL: "https://localhost",
@@ -227,12 +227,13 @@ func (t *Tester) GetCreatedManagedCluster(clusterName string) (*clusterv1.Manage
 }
 
 func (t *Tester) ApproveCSR(clusterName string) error {
-	var csrs *certificatesv1beta1.CertificateSigningRequestList
-	var csrClient = t.KubeClient.CertificatesV1beta1().CertificateSigningRequests()
+	var csrs *certificatesv1.CertificateSigningRequestList
+	var csrClient = t.KubeClient.CertificatesV1().CertificateSigningRequests()
 	var err error
 
 	if csrs, err = csrClient.List(context.TODO(), metav1.ListOptions{
 		LabelSelector: fmt.Sprintf("open-cluster-management.io/cluster-name = %v", clusterName)}); err != nil {
+		klog.Errorf("failed to list csr %v.err %v", clusterName, err)
 		return err
 	}
 	if len(csrs.Items) == 0 {
@@ -242,6 +243,7 @@ func (t *Tester) ApproveCSR(clusterName string) error {
 	for i := range csrs.Items {
 		csr := &csrs.Items[i]
 		if csr, err = csrClient.Get(context.TODO(), csr.Name, metav1.GetOptions{}); err != nil {
+			klog.Errorf("failed to get csr %v.err %v", clusterName, err)
 			return err
 		}
 
@@ -249,25 +251,27 @@ func (t *Tester) ApproveCSR(clusterName string) error {
 			return nil
 		}
 
-		csr.Status.Conditions = append(csr.Status.Conditions, certificatesv1beta1.CertificateSigningRequestCondition{
-			Type:    certificatesv1beta1.CertificateApproved,
+		csr.Status.Conditions = append(csr.Status.Conditions, certificatesv1.CertificateSigningRequestCondition{
+			Type:    certificatesv1.CertificateApproved,
+			Status:  corev1.ConditionTrue,
 			Reason:  "Approved by E2E",
 			Message: "Approved as part of e2e",
 		})
-		_, err = csrClient.UpdateApproval(context.TODO(), csr, metav1.UpdateOptions{})
+		_, err = csrClient.UpdateApproval(context.TODO(), csr.Name, csr, metav1.UpdateOptions{})
 		if err != nil {
+			klog.Errorf("failed to updateApproval csr %v.err %v", clusterName, err)
 			return err
 		}
 	}
 	return nil
 }
 
-func isCSRInTerminalState(status *certificatesv1beta1.CertificateSigningRequestStatus) bool {
+func isCSRInTerminalState(status *certificatesv1.CertificateSigningRequestStatus) bool {
 	for _, c := range status.Conditions {
-		if c.Type == certificatesv1beta1.CertificateApproved {
+		if c.Type == certificatesv1.CertificateApproved {
 			return true
 		}
-		if c.Type == certificatesv1beta1.CertificateDenied {
+		if c.Type == certificatesv1.CertificateDenied {
 			return true
 		}
 	}
